@@ -112,9 +112,19 @@ def build_workspace(config_file, args):
 
     try:
         builder.build()
+
+        if 'TMUX' in os.environ:
+            if query_yes_no('Already inside TMUX, load session?'):
+                del os.environ['TMUX']
+                os.execl(tmux_bin, 'tmux', 'switch-client', '-t', sconfig['session_name'])
+
         os.execl(tmux_bin, 'tmux', 'attach-session', '-t', sconfig['session_name'])
     except exc.TmuxSessionExists as e:
-        attach_session = query_yes_no(e.message + ' attach?')
+        attach_session = query_yes_no(e.message + ' Attach?')
+
+        if 'TMUX' in os.environ:
+            del os.environ['TMUX']
+            os.execl(tmux_bin, 'tmux', 'switch-client', '-t', sconfig['session_name'])
 
         if attach_session:
             os.execl(tmux_bin, 'tmux', 'attach-session', '-t', sconfig['session_name'])
@@ -186,7 +196,10 @@ def main():
     elif args.configs:
         if '.' in args.configs:
             args.configs.remove('.')
-            args.configs.append(config.in_cwd()[0])
+            if config.in_cwd():
+                args.configs.append(config.in_cwd()[0])
+            else:
+                print('No tmuxp configs found in current directory.')
 
         for configfile in args.configs:
             file_user = os.path.join(config_dir, configfile)
